<?php

namespace Drupal\couchbasedrupal\Cache;

/**
 * Custom override of cache factory
 * to allow overriding default backends to use
 * couchbase instead of database.
 */
class CacheFactory extends \Drupal\Core\Cache\CacheFactory {
  /**
   * {@inhertidoc}
   */
  public function get($bin) {
    $cache_settings = $this->settings->get('cache');
    // First, look for a cache bin specific setting.
    if (isset($cache_settings['bins'][$bin])) {
      $service_name = $cache_settings['bins'][$bin];
    }
    // Second, use the default backend specified by the cache bin.
    elseif (isset($this->defaultBinBackends[$bin])) {
      $service_name = $this->defaultBinBackends[$bin];
    }
    // Third, use configured default backend.
    elseif (isset($cache_settings['default'])) {
      $service_name = $cache_settings['default'];
    }
    else {
      // Fall back to the couchbase backend if nothing else is configured.
      $service_name = 'cache.backend.couchbase';
    }
    return $this->container->get($service_name)->get($bin);
  }
}